#####
Passy
#####

| A credential handler package for avoiding side channel attacks.

.......
Install
.......

To install using pip::

    pip install Passy
    or
    python -m pip install Passy

..........
quickstart
..........



.............
Contributions
.............

If you would like to help to develop::

    pip install -e .[dev]

| This installs all development modules alongside the main package
| Any contributions would be greatly appricated
